pub struct ProbeHit {
pub distance: f32,
pub point: Vec3,
pub element: Option<ElementId>,
pub node: Option<NodeId>,
pub value: Option<f32>,
}Fields
distance: f32point: Vec3Sample location: selected vertex for a nodal field, hit point for an element field.
element: Option<ElementId>node: Option<NodeId>Some only for nodal fields. The value is sampled at this triangle vertex, not interpolated at the cursor and not converted to an element result.
value: Option<f32>Trait Implementations